@@ -197,5 +197,5 @@ class AutopilotMavic2DJI(AutopilotControlledDrone):
         while self.step(self.basic_time_step) != -1:
             # For now just actuate
             # print(self.get_distance_from_target())
-            # self.actuate()
-            self.get_input()
+            self.actuate()
+            # self.get_input()
